@@ -45,16 +45,17 @@ Some stuff won't be trivial to understand, but comments and fixes are welcome
 """
 import datetime as dt
 from functools import lru_cache
-import warnings
 
 from sgp4 import ext, model
+from sgp4.api import Satrec, SGP4_ERRORS
 from sgp4.earth_gravity import wgs84
-from sgp4.io import twoline2rv
-from sgp4.propagation import _gstime
+from sgp4.model import WGS84
+from sgp4.propagation import gstime
 
 from orbit_predictor import coordinate_systems
+from ..exceptions import PropagationError
 
-from ..utils import reify, timetuple_from_dt
+from ..utils import reify, jday_from_datetime, unkozai
 from .base import CartesianPredictor
 
 # Hack Zone be warned
@@ -85,6 +86,23 @@ class HighAccuracyTLEPredictor(CartesianPredictor):
     def __init__(self, sate_id, source):
         self._sate_id = sate_id
         self._source = source
+        self.tle = self._source.get_tle(self.sate_id, dt.datetime.utcnow())
+        self._propagator = self._get_propagator()
+
+    def _get_propagator(self):
+        tle_line_1, tle_line_2 = self.tle.lines
+        return Satrec.twoline2rv(tle_line_1, tle_line_2, WGS84)
+
+    def __getstate__(self):
+        # See https://docs.python.org/3/library/pickle.html#handling-stateful-objects
+        state = self.__dict__.copy()
+        del state["_propagator"]
+        return state
+
+    def __setstate__(self, state):
+        # See https://docs.python.org/3/library/pickle.html#handling-stateful-objects
+        self.__dict__.update(state)
+        self._propagator = self._get_propagator()
 
     @property
     def sate_id(self):
@@ -94,44 +112,32 @@ class HighAccuracyTLEPredictor(CartesianPredictor):
     def source(self):
         return self._source
 
-    @reify
-    def tle(self):
-        return self._source.get_tle(self.sate_id, dt.datetime.utcnow())
-
-    @reify
-    def _propagator(self):
-        tle_line_1, tle_line_2 = self.tle.lines
-        return twoline2rv(tle_line_1, tle_line_2, wgs84)
-
-    @reify
-    def propagator(self):
-        warnings.warn(
-            "The .propagator property will be made private in a future release",
-            DeprecationWarning
-        )
-        return self._propagator
-
     @reify
     def mean_motion(self):
         """Mean motion, in radians per minute"""
-        return self._propagator.no_unkozai
+        return unkozai(
+            self._propagator.no_kozai, self._propagator.ecco, self._propagator.inclo, wgs84
+        )
 
     @lru_cache(maxsize=3600 * 24 * 7)  # Max cache, a week
-    def _propagate_only_position_ecef(self, timetuple):
+    def _propagate_only_position_ecef(self, when_utc):
         """Return position in the given date using ECEF coordinate system."""
-        position_eci, _ = self._propagator.propagate(*timetuple)
-        gmst = _gstime(jday(*timetuple))
+        jd, fr = jday_from_datetime(when_utc)
+        status, position_eci, _ = self._propagator.sgp4(jd, fr)
+        if status != 0:
+            raise PropagationError(SGP4_ERRORS[status])
+
+        gmst = gstime(jd + fr)
         return coordinate_systems.eci_to_ecef(position_eci, gmst)
 
     def propagate_eci(self, when_utc=None):
         if when_utc is None:
             when_utc = dt.datetime.utcnow()
 
-        timetuple = timetuple_from_dt(when_utc)
-
-        position_eci, velocity_eci = self._propagator.propagate(*timetuple)
-        if self._propagator.error != 0:
-            raise RuntimeError(self._propagator.error_message)
+        jd, fr = jday_from_datetime(when_utc)
+        status, position_eci, velocity_eci = self._propagator.sgp4(jd, fr)
+        if status != 0:
+            raise PropagationError(SGP4_ERRORS[status])
 
         return position_eci, velocity_eci
 
@@ -143,5 +149,4 @@ class HighAccuracyTLEPredictor(CartesianPredictor):
         if when_utc is None:
             when_utc = dt.datetime.utcnow()
 
-        timetuple = timetuple_from_dt(when_utc)
-        return self._propagate_only_position_ecef(timetuple)
+        return self._propagate_only_position_ecef(when_utc)
